@@ -209,7 +209,7 @@ def setup_hyp(exp_name, cfg, checkpoint_dir, params={}, label_map=[]):
     for f in tmp:
         if f.endswith('.pt'):
             weight_path = os.path.join(checkpoint_dir, f)
-        if f.endswith('{}.yaml'.format(exp_name)):
+        if f.endswith('.yaml'.format(exp_name)):
             hyp_path = os.path.join(checkpoint_dir, f)
     
 
@@ -251,5 +251,91 @@ def setup_hyp(exp_name, cfg, checkpoint_dir, params={}, label_map=[]):
     device = 'cuda:0' if torch.cuda.is_available() else 'cpu'
     return hyp, opt, device
 
+def find_final_run(YOLODIR, exp_name):
+    runs_path = os.path.join(YOLODIR, 'runs', 'train')
+    dirs = os.listdir(runs_path)
+    if len(dirs) == 1:
+        return os.path.join(runs_path, dirs[0])
+    base = dirs[0][:7]
+    lower_exp_name = exp_name.replace('-', '_')
+    name = base + '_' + lower_exp_name
+    truncate_dirs = [int(n[len(name)-1:]) for n in dirs]
+    last_run_nb = max(truncate_dirs)
+    return os.path.join(runs_path, name + str(last_run_nb))
+
+def get_batch_mosaics(final_run_path):
+    test_batch0_labels = None
+    test_batch0_pred = None
+    test_batch1_labels = None
+    test_batch1_pred = None
+    test_batch2_labels = None
+    test_batch2_pred = None
+    if os.path.isfile(os.path.join(final_run_path, 'test_batch0_labels.jpg')):
+        test_batch0_labels = os.path.join(final_run_path, 'test_batch0_labels.jpg')
+    if os.path.isfile(os.path.join(final_run_path, 'test_batch0_pred.jpg')):
+        test_batch0_pred = os.path.join(final_run_path, 'test_batch0_pred.jpg')
+    if os.path.isfile(os.path.join(final_run_path, 'test_batch1_labels.jpg')):
+        test_batch1_labels = os.path.join(final_run_path, 'test_batch1_labels.jpg')
+    if os.path.isfile(os.path.join(final_run_path, 'test_batch1_pred.jpg')):
+        test_batch1_pred = os.path.join(final_run_path, 'test_batch1_pred.jpg')
+    if os.path.isfile(os.path.join(final_run_path, 'test_batch2_labels.jpg')):
+        test_batch2_labels = os.path.join(final_run_path, 'test_batch2_labels.jpg')
+    if os.path.isfile(os.path.join(final_run_path, 'test_batch2_pred.jpg')):
+        test_batch2_pred = os.path.join(final_run_path, 'test_batch2_pred.jpg')
+    return test_batch0_labels, test_batch0_pred, test_batch1_labels, test_batch1_pred, test_batch2_labels, test_batch2_pred
+
+def get_weights_and_config(final_run_path):
+    last_weights = None
+    best_weights = None
+    hyp_yaml = None
+    if os.path.isfile(os.path.join(final_run_path, 'weights', 'best.pt')):
+        best_weights = os.path.join(final_run_path, 'weights', 'best.pt')
+    if os.path.isfile(os.path.join(final_run_path, 'weights', 'last.pt')):
+        last_weights = os.path.join(final_run_path, 'weights', 'last.pt')
+    if os.path.isfile(os.path.join(final_run_path, 'hyp.yaml')):
+        hyp_yaml = os.path.join(final_run_path, 'hyp.yaml')
+    return best_weights, last_weights, hyp_yaml
+
+def get_metrics_curves(final_run_path):
+    confusion_matrix = None
+    F1_curve = None
+    labels_correlogram = None
+    P_curve = None
+    PR_curve = None
+    R_curve = None
+    if os.path.isfile(os.path.join(final_run_path, 'confusion_matrix.png')):
+        confusion_matrix = os.path.join(final_run_path, 'confusion_matrix.png')
+    if os.path.isfile(os.path.join(final_run_path, 'F1_curve.png')):
+        F1_curve = os.path.join(final_run_path, 'F1_curve.png')
+    if os.path.isfile(os.path.join(final_run_path, 'labels_correlogram.jpg')):
+        labels_correlogram = os.path.join(final_run_path, 'labels_correlogram.jpg')
+    if os.path.isfile(os.path.join(final_run_path, 'P_curve.png')):
+        P_curve = os.path.join(final_run_path, 'P_curve.png')
+    if os.path.isfile(os.path.join(final_run_path, 'PR_curve.png')):
+        PR_curve = os.path.join(final_run_path, 'PR_curve.png')
+    if os.path.isfile(os.path.join(final_run_path, 'R_curve.png')):
+        R_curve = os.path.join(final_run_path, 'R_curve.png')
+    return confusion_matrix, F1_curve, labels_correlogram, P_curve, PR_curve, R_curve
+
+def send_run_to_picsellia(experiment, YOLODIR):
+    final_run_path = find_final_run(YOLODIR, experiment.experiment_name)
+    best_weigths, last_weights, hyp_yaml = get_weights_and_config(final_run_path)
+
+    if best_weigths is not None:
+        experiment.store('best-weights', best_weigths)
+    if last_weights is not None:
+        experiment.store('last-weights', last_weights)
+    if hyp_yaml is not None:
+        experiment.store('checkpoint-data-latest', hyp_yaml)
+    for curve in get_metrics_curves(final_run_path):
+        if curve is not None:
+            name = curve.split('/')[-1].split('.')[0]
+            experiment.log(name, curve, 'image')
+    for batch in get_batch_mosaics(final_run_path):
+        if batch is not None:
+            name = batch.split('/')[-1].split('.')[0]
+            experiment.log(name, batch, 'image')
+
+
 class Opt():
     pass
\ No newline at end of file
