@@ -373,23 +373,27 @@ def train(hyp, opt, device, tb_writer=None, wandb=None, pxl=None):
                     'metrics/precision', 'metrics/recall', 'metrics/mAP_0.5', 'metrics/mAP_0.5:0.95',
                     'val/box_loss', 'val/obj_loss', 'val/cls_loss',  # val loss
                     'x/lr0', 'x/lr1', 'x/lr2']  # params
+            verified_tags = ['metrics/precision', 'metrics/recall', 'metrics/mAP_0.5', 'metrics/mAP_0.5:0.95',
+                    'val/box_loss', 'val/obj_loss', 'val/cls_loss',  # val loss
+                    'x/lr0', 'x/lr1', 'x/lr2']  # params
             for x, tag in zip(list(mloss[:-1]) + list(results) + lr, tags):
                 if tb_writer:
                     tb_writer.add_scalar(tag, x, epoch)  # tensorboard
                 if wandb:
                     wandb.log({tag: x}, step=epoch, commit=tag == tags[-1])  # W&B
                 if pxl:
-                    try:
-                        name = str(tag).replace('/', '_')
-                        pxl.log(name=name, type='line', data=[x])
-                    except Exception as e:
-                        logger.info(str(e))
+                    if tag in verified_tags:
                         try:
-                            #name = tag.cpu()
                             name = str(tag).replace('/', '_')
-                            pxl.log(name=name, type='line', data=x.cpu().numpy())
-                        except:
-                            print(tag, "can't be uploaded")
+                            pxl.log(name=name, type='line', data=[x])
+                        except Exception as e:
+                            logger.info(str(e))
+                            try:
+                                #name = tag.cpu()
+                                name = str(tag).replace('/', '_')
+                                pxl.log(name=name, type='line', data=x.cpu().numpy())
+                            except:
+                                print(tag, "can't be uploaded")
             # Update best mAP
             fi = fitness(np.array(results).reshape(1, -1))  # weighted combination of [P, R, mAP@.5, mAP@.5-.95]
             if fi > best_fitness:
